from setuptools import setup, find_packages
import os

# 读取 README.md 的内容
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="llmrf",
    version="0.1.1",
    description="轻量级的 LLM 响应格式化工具，支持标准响应和流式响应",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="满天翔",
    author_email="2722843861@qq.com",
    url="https://github.com/cchking/llmrf",
    packages=find_packages(),
    python_requires=">=3.6",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)


import time
import json
import uuid

class RF:
    def __init__(self):
        self.default_id = f"chatcmpl-{str(uuid.uuid4())}"
        self.default_model = "gpt-3.5-turbo"
        
    def f_r(self, content, stream=False, **kwargs):
        id = kwargs.get('id', self.default_id)
        model = kwargs.get('model', self.default_model)
        created = kwargs.get('created', int(time.time()))
        
        return self._stream(content, model) if stream else self._normal(content, id, model, created)
    
    def _normal(self, content, id, model, created):
        return {
            "id": id,
            "object": "chat.completion",
            "created": created,
            "model": model,
            "choices": [{
                "index": 0,
                "message": {
                    "role": "assistant",
                    "content": content
                },
                "finish_reason": "stop"
            }],
            "usage": {
                "prompt_tokens": len(content),
                "completion_tokens": len(content),
                "total_tokens": len(content) * 2
            }
        }
    
    def _stream(self, content, model):
        chunk = {
            "id": None,
            "object": "chat.completion.chunk",
            "created": None,
            "model": model,
            "choices": [{
                "index": 0,
                "delta": {
                    "content": content,
                    "role": None
                },
                "finish_reason": None
            }],
            "usage": None
        }
        return [
            f"data: {json.dumps(chunk, ensure_ascii=False)}\n\n",
            "data: [DONE]\n\n"
        ]